==> kubernetes-model-networking-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/networking/v1alpha1/IPAddressSpecFluent.java <==
package io.fabric8.kubernetes.api.model.networking.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class IPAddressSpecFluent<A extends IPAddressSpecFluent<A>> extends BaseFluent<A>{
  public IPAddressSpecFluent() {
  }
  public IPAddressSpecFluent(IPAddressSpec instance) {
    instance = (instance != null ? instance : new IPAddressSpec());

    if (instance != null) {
      this.withParentRef(instance.getParentRef());
      this.withParentRef(instance.getParentRef());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ParentReferenceBuilder parentRef;
  private Map<String,Object> additionalProperties;
  public ParentReference buildParentRef() {
    return this.parentRef!=null ?this.parentRef.build():null;
  }
  public A withParentRef(ParentReference parentRef) {
    _visitables.get("parentRef").remove(this.parentRef);
    if (parentRef!=null){ this.parentRef= new ParentReferenceBuilder(parentRef); _visitables.get("parentRef").add(this.parentRef);} else { this.parentRef = null; _visitables.get("parentRef").remove(this.parentRef); } return (A) this;
  }
  public boolean hasParentRef() {
    return this.parentRef != null;
  }
  public A withNewParentRef(String group,String name,String namespace,String resource,String uid) {
    return (A)withParentRef(new ParentReference(group, name, namespace, resource, uid));
  }
  public ParentRefNested<A> withNewParentRef() {
    return new ParentRefNested(null);
  }
  public ParentRefNested<A> withNewParentRefLike(ParentReference item) {
    return new ParentRefNested(item);
  }
  public ParentRefNested<A> editParentRef() {
    return withNewParentRefLike(java.util.Optional.ofNullable(buildParentRef()).orElse(null));
  }
  public ParentRefNested<A> editOrNewParentRef() {
    return withNewParentRefLike(java.util.Optional.ofNullable(buildParentRef()).orElse(new ParentReferenceBuilder().build()));
  }
  public ParentRefNested<A> editOrNewParentRefLike(ParentReference item) {
    return withNewParentRefLike(java.util.Optional.ofNullable(buildParentRef()).orElse(item));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IPAddressSpecFluent that = (IPAddressSpecFluent) o;
    if (!java.util.Objects.equals(parentRef, that.parentRef)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(parentRef,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (parentRef != null) { sb.append("parentRef:"); sb.append(parentRef + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ParentRefNested<N> extends ParentReferenceFluent<ParentRefNested<N>> implements Nested<N>{
    ParentRefNested(ParentReference item) {
      this.builder = new ParentReferenceBuilder(this, item);
    }
    ParentReferenceBuilder builder;
    public N and() {
      return (N) IPAddressSpecFluent.this.withParentRef(builder.build());
    }
    public N endParentRef() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-networking-6.9.0-sources.jar: io/fabric8/kubernetes/api/model/networking/v1alpha1/IPAddressSpecFluent.java <==
package io.fabric8.kubernetes.api.model.networking.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class IPAddressSpecFluent<A extends IPAddressSpecFluent<A>> extends BaseFluent<A>{
  public IPAddressSpecFluent() {
  }
  
  public IPAddressSpecFluent(IPAddressSpec instance) {
    this.copyInstance(instance);
  }
  private ParentReferenceBuilder parentRef;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(IPAddressSpec instance) {
    instance = (instance != null ? instance : new IPAddressSpec());
  
    if (instance != null) {
        this.withParentRef(instance.getParentRef());
        this.withParentRef(instance.getParentRef());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public ParentReference buildParentRef() {
    return this.parentRef!=null ?this.parentRef.build():null;
  }
  
  public A withParentRef(ParentReference parentRef) {
    _visitables.get("parentRef").remove(this.parentRef);
    if (parentRef!=null){ this.parentRef= new ParentReferenceBuilder(parentRef); _visitables.get("parentRef").add(this.parentRef);} else { this.parentRef = null; _visitables.get("parentRef").remove(this.parentRef); } return (A) this;
  }
  
  public boolean hasParentRef() {
    return this.parentRef != null;
  }
  
  public A withNewParentRef(String group,String name,String namespace,String resource,String uid) {
    return (A)withParentRef(new ParentReference(group, name, namespace, resource, uid));
  }
  
  public ParentRefNested<A> withNewParentRef() {
    return new ParentRefNested(null);
  }
  
  public ParentRefNested<A> withNewParentRefLike(ParentReference item) {
    return new ParentRefNested(item);
  }
  
  public ParentRefNested<A> editParentRef() {
    return withNewParentRefLike(java.util.Optional.ofNullable(buildParentRef()).orElse(null));
  }
  
  public ParentRefNested<A> editOrNewParentRef() {
    return withNewParentRefLike(java.util.Optional.ofNullable(buildParentRef()).orElse(new ParentReferenceBuilder().build()));
  }
  
  public ParentRefNested<A> editOrNewParentRefLike(ParentReference item) {
    return withNewParentRefLike(java.util.Optional.ofNullable(buildParentRef()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IPAddressSpecFluent that = (IPAddressSpecFluent) o;
    if (!java.util.Objects.equals(parentRef, that.parentRef)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(parentRef,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (parentRef != null) { sb.append("parentRef:"); sb.append(parentRef + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ParentRefNested<N> extends ParentReferenceFluent<ParentRefNested<N>> implements Nested<N>{
    ParentRefNested(ParentReference item) {
      this.builder = new ParentReferenceBuilder(this, item);
    }
    ParentReferenceBuilder builder;
    
    public N and() {
      return (N) IPAddressSpecFluent.this.withParentRef(builder.build());
    }
    
    public N endParentRef() {
      return and();
    }
    
  
  }

}
